Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

class miml.transformation.mimlTOmi.binary_relevance_transformation.BinaryRelevanceTransformation

  Bases: `object`

  Class that performs a binary relevance transformation to convert a MIMLDataset class to numpy ndarray.

  transform_bag(bag: Bag) → list

    Transform miml bag to multi instance bags

    # Parameters

    bag :

      Bag to be transformed to multi-instance bag

    # Returns

    bagslist[Bag]

      List of n_labels transformed bags

  transform_dataset(dataset: MIMLDataset) → list

    Transform the dataset to multi-instance datasets dividing the original dataset into n datasets with a single label, where n is the number of labels.

    # Returns

    datasets: list

      Multi instance datasets